TextLCD library for controlling various LCD panels based on the HD44780 4-bit interface. adapted for winstar oled display by CJS august 2012. Moved some functions into public class to enable custom character generation from user code.

Dependents:   CCRMonitor12_sp07_120ver

Fork of TextLCD by Simon Ford

Revision:
12:4d8dcfa5af6e
Parent:
11:25a700bce989
--- a/TextOLED.cpp	Mon Jan 14 12:51:35 2013 +0000
+++ b/TextOLED.cpp	Fri Apr 12 10:14:55 2013 +0000
@@ -31,7 +31,7 @@
     _e  = 1;
     _rs = 0;            // command mode
 
-   wait(0.100);        // Wait 100ms to ensure powered up - need this long if run of 3.3V from mbed vout
+   wait(0.500);        // Wait 500ms to ensure powered up - need this long if run of 3.3V from mbed vout
 
    wait(0.015); //wait `15ms for power up